#' @title Download and Display Map Tiles
#' @name maptiles
#' @rdname maptiles
#' @description
#' To create maps from tiles, maptiles downloads, composes and displays tiles
#' from a large number of providers (e.g. OpenStreetMap, Stamen, Esri, CARTO,
#' or Thunderforest).
#' @docType package
"_PACKAGE"
